#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define service go_modules
%if 0%{?suse_version} >= 1315 || 0%{?fedora_version} >= 29
%bcond_without python3
%else
%bcond_with    python3
%endif
# This list probably needs to be extended
# logic seems to be if python < 2.7 ; then needs_external_argparse ; fi
%if (0%{?centos_version} == 6) || (0%{?suse_version} && 0%{?suse_version} < 1315) || (0%{?fedora_version} && 0%{?fedora_version} < 26)
%bcond_without needs_external_argparse
%else
%bcond_with    needs_external_argparse
%endif
%if %{with python3}
%define use_python python3
%define use_test   test3
%else
%define use_python python
%define use_test   test
%endif
Name:           obs-service-%{service}
Version:        0.6.4
Release:        1.1
Summary:        An OBS source service: Download, verify and vendor Go module dependencies
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
URL:            https://github.com/openSUSE/obs-service-%{service}
Source:         %{name}-%{version}.tar.gz
BuildRequires:  go-md2man
Requires:       python3-libarchive-c
Requires:       golang(API) >= 1.21
BuildArch:      noarch
%if %{with needs_external_argparse}
BuildRequires:  %{use_python}-argparse
%endif
%if %{with python3}
BuildRequires:  %{use_python}
# Fix missing Requires in python3-pbr in Leap42.3
BuildRequires:  %{use_python}-setuptools
%endif

%description
An OBS Source Service that will download,
verify and vendor Go module dependency sources.

Using go.mod and go.sum present in a Go application,
the source service will call Go tools in sequence:

go mod download
go mod verify
go mod vendor

Then create a vendor.tar.gz populated with the contents of
vendor/

%prep
%setup -q

%build

%install
mkdir -p %{buildroot}%{_prefix}/lib/obs/service
mkdir -p %{buildroot}%{_prefix}/lib/obs/service
install -m 0755 go_modules %{buildroot}%{_prefix}/lib/obs/service
install -m 0644 go_modules.service %{buildroot}%{_prefix}/lib/obs/service

# Build the man page from markdown documentation.
go-md2man -in README.md -out %{name}.1

# Install the man page.
install -D -m 0644 %{name}.1 "%{buildroot}/%{_mandir}/man1/%{name}.1"
rm %{name}.1

%files
%doc README.md
%license LICENSE
%dir %{_prefix}/lib/obs
%{_prefix}/lib/obs/service
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Thu Oct 26 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.6.4:
  * go_modules: allow globbing in the "archive" name field
  * Reformat with black 23.x
- Packaging improvements:
  * _service change disabled to manual per osc deprecation warning:
    WARNING: Command 'disabledrun/dr' is obsolete, please convert
    your _service to use 'manual' and then 'manualrun/mr' instead.
* Mon Oct  9 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Use BuildRequires: golang(API) >= 1.21 instead of go >= 1.21
  * The recommended Go toolchain dependency expression is
    BuildRequires: golang(API) >= 1.x or optionally the metapackage
    BuildRequires: go
  * The go metapackage points to a single go version that
    increments at a date TBD after each go1.x major release. The
    expression golang(API) is available immediately upon each go1.x
    major release and is stable for expressing the minimum version
    or a temporarily pinned version.
  * Refs boo#1214933
  * Refs https://github.com/openSUSE/obs-service-go_modules/issues/33
* Sat Oct  7 2023 Johannes Kastl <kastl@b1-systems.de>
- Require go1.21 to make sure it works with go.mod files that
  contain a three-digit-version (e.g. 1.21.1). Fixes boo#1214933
  and https://github.com/openSUSE/obs-service-go_modules/issues/33
* Mon Apr  3 2023 dmueller@suse.com
- Update to version 0.6.3:
  * Rename new argument vendorfilename to vendorname
  * Fix default vendorfilename
  * make vendor tarball name configurable (#27)
  * Fix autodetection for zst/zstd confusion
  * README.md: hint on avoiding errors if local git clone already exists
  * README.md: add example for use of archive parameter
  * Format source with python black refs #29
  * Revert wrap of long lines flake8 recommends but black accepts refs #29
  * flake8 config black compat extend-ignore E501 line too long refs #29
  * Add GitHub CI action to run Black formatter on file go_modules
  * Flake8 A002 argument "dir" is shadowing a python builtin
  * Flake8 C413 Unnecessary reversed(sorted()) use sorted(reverse=True)
  * Flake8 C413 fix extraneous closing perentheses in sorted()
  * Flake8 C413 Unnecessary reversed(sorted()) use sorted(reverse=True)
  * Fix flake8 CI action YAML indent plugins: under with: key
* Mon Mar 27 2023 dmueller@suse.com
- Update to version 0.6.2:
  * Better skipping of non-compressed archive extensions (like .tar.gz.asc)
  * Adjust flake8 settings to match what black is doing
  * fix flake8 errors and add flake8 Github Action (#28)
* Thu Mar  2 2023 jkowalczyk@suse.com
- Update to version 0.6.1:
  * README for pull requests enable maintainer edit permissions
  * Fix parser errors in service file XML formedness and special chars
* Mon Feb 27 2023 jkowalczyk@suse.com
- Update to version 0.6.0:
  * Make service arg subdir optional
  * exit(1) immediately in extract() exception handler after recording error
  * Use subprocess.run() options 'capture_output' & 'text' only when supported
  * Add '--subdir' option: all to specify the directory to search go.mod in
  * Use temporary directory to extract archive to
  * Give the user the opprtunity to specify the name of the topmost directory
  * Attempt to obtain name of top directory in archive from archive content
    (CVE-2022-45155, bsc#1201138, bsc#1201140).
* Sat Jun 11 2022 jkowalczyk@suse.com
- Update to version 0.5.0:
  * README update
  * Check go mod subcommand return code, log and exit on error
  * Log go.mod file not found as error not info
  * Execute go mod subcommands using subprocess.run()
  * Rework the service to better work with obs_scm
- Add Require: python3-libarchive-c
- Drop Require: tar
- Drop Require: gzip
* Mon May  2 2022 dmueller@suse.com
- Update to version 0.4.1:
  * Fix compression parameter default value usage
* Tue Apr 26 2022 dmueller@suse.com
- Update to version 0.4.0:
  * don't ignore go mod command errors
  * allow specifying source / vendor archive compression mode
* Mon Sep  2 2019 jkowalczyk@suse.com
- Update to version 0.3.0:
  * Add check for version agreement with .spec to archive autodetection
  * README add example _service configuration
  * README update FAQ entries regarding Go module cache
  * README update example to reflect current log output
  * Add Go source archive autodetection based on RPM spec file name
  * Add missing parameter archive to definition go_modules.service
  * Add exception handling around shutil.rmtree for extracted archive
  * README fix hyperlink
  * README cite openSUSE packages built using obs-service-go_modules
  * Reduce python module __doc__ from full copy to subset of README
  * Packaging tar_scm service use revision instead of version to
    fix use of _servicedata for changelog generation
* Mon Aug  5 2019 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update upstream repository location now in openSUSE organization
* Mon Aug  5 2019 jkowalczyk@suse.com
- Update to version 0.2.1:
  * README documentation improvements
* Thu Aug  1 2019 Jeff Kowalczyk <jkowalczyk@suse.com>
- obs-service-go_modules (0.2.0 released 2019/08/01) is the first
  packaged release for review and feedback. This OBS Source Service
  will download, verify and vendor Go module dependencies expressed
  in the file go.mod.  By vendoring all dependencies during the OBS
  Source Service stage, go build commands can run in the offline
  OBS build environment. This initial version:
  * Tested by packaging devel:languages:go/hugo, which has the
    typical Go application unpacked layout containing go.mod at:
    hugo-0.56.3/go.mod
  * Supports tar.gz archives in the form
    hugo-0.56.3.tar.gz -> hugo-0.56.3/
    Other archive format and layout support to be added as needed
  * Produces vendor.tar.gz
    vendor.cpio archive support planned
  * Replace print() with logging facilities
  * Fix indentation for cmd_go_mod() return values
  * Return non-zero exit codes on failure
